@@ -11,7 +11,6 @@ Created on 27 Sep 2020
 '''
 
 UBX_HDR = b'\xB5\x62'
-NMEA_HDR = b'\x24'  # '$'
 INPUT = 0
 OUTPUT = 1
 GET = 0
@@ -27,6 +26,7 @@ X1 = 'X01'  # Bitfield 1
 U2 = 'U02'  # Unsigned Short
 I2 = 'I02'  # Signed Short
 X2 = 'X02'  # Bitfield 2
+U3 = 'U03'  # Unsigned Long 3
 U4 = 'U04'  # Unsigned Long 4
 I4 = 'I04'  # Signed Long 4 2's complement
 X4 = 'X04'  # Bitfield 4
@@ -38,7 +38,7 @@ C10 = 'C10'  # ASCII / ISO 8859.1 Encoding 10
 C30 = 'C30'  # ASCII / ISO 8859.1 Encoding 30
 C32 = 'C32'  # ASCII / ISO 8859.1 Encoding 32
 CH = 'CH'  # ASCII / ISO 8859.1 Encoding Variable Length
-VALID_TYPES = (U1, I1, X1, U2, I2, X2, U4, I4 , X4 , R4 , R8 , X6, C06, C10, C30, C32, CH)
+VALID_TYPES = (U1, I1, X1, U2, I2, X2, U3, U4, I4 , X4 , R4 , R8 , X6, C06, C10, C30, C32, CH)
 
 '''
 THESE ARE THE UBX PROTOCOL MESSAGE CLASSES
@@ -116,28 +116,50 @@ b'\x03':'INF-TEST',
 b'\x01':'INF-WARNING'},
 # MON
 b'\x0A':{
+b'\x28':'MON-GNSS', 
 b'\x0B':'MON-HW2',
 b'\x09':'MON-HW',
 b'\x02':'MON-IO',
 b'\x06':'MON-MSGPP',
+b'\x27':'MON-PATCH',
 b'\x07':'MON-RXBUF',
 b'\x21':'MON-RXR',
+b'\x2E':'MON-SMGR',
 b'\x08':'MON-TXBUF',
 b'\x04':'MON-VER'},
 #  NAV
 b'\x01':{
 b'\x60':'NAV-AOPSTATUS',
+b'\x05':'NAV-ATT',  # TODO
 b'\x22':'NAV-CLOCK',
 b'\x31':'NAV-DGPS',
 b'\x04':'NAV-DOP',
 b'\x40':'NAV-EKFSTATUS',
+b'\x61':'NAV-EOE',
+b'\x39':'NAV-GEOFENCE',
+b'\x13':'NAV-HPPOSECEF',  # TODO
+b'\x14':'NAV-HPPOSLLH',  # TODO
+b'\x28':'NAV-NMI',  # TODO
+b'\x09':'NAV-ODO',
+b'\x34':'NAV-ORB',
 b'\x01':'NAV-POSECEF',
 b'\x02':'NAV-POSLLH',
+b'\x07':'NAV-PVT',
+b'\x3C':'NAV-RELPOSNED',  # TODO
+b'\x35':'NAV-SAT',
 b'\x32':'NAV-SBAS',
+b'\x43':'NAV-SIG',  # TODO
+b'\x42':'NAV-SLAS',  # TODO
 b'\x06':'NAV-SOL',
 b'\x03':'NAV-STATUS',
 b'\x30':'NAV-SVINFO',
+b'\x3B':'NAV-SVIN',  # TODO
+b'\x24':'NAV-TIMEBDS',
+b'\x25':'NAV-TIMEGAL',
+b'\x23':'NAV-TIMEGLO',
 b'\x20':'NAV-TIMEGPS',
+b'\x26':'NAV-TIMELS',
+b'\x27':'NAV-TIMEQZSS',  # TODO
 b'\x21':'NAV-TIMEUTC',
 b'\x11':'NAV-VELECEF',
 b'\x12':'NAV-VELNED'},
@@ -187,18 +209,21 @@ NB: Available messages will depend on the receiver
 '''
 # TODO add additional UBX message types for AID, RXM, ESF
 UBX_CONFIG_MESSAGES = {
-b'\x0A\x36': 'MON-COMMS',
+# b'\x0A\x36': 'MON-COMMS',
+b'\x0A\x28': 'MON-GNSS',
 b'\x0A\x09': 'MON-HW',
 b'\x0A\x0B': 'MON-HW2',
-b'\x0A\x37': 'MON-HW3',
+# b'\x0A\x37': 'MON-HW3',
 b'\x0A\x02': 'MON-IO',
 b'\x0A\x06': 'MON-MSGPP',
-b'\x0A\x38': 'MON-RF',
+b'\x0A\x27': 'MON-PATCH',
+# b'\x0A\x38': 'MON-RF',
 b'\x0A\x07': 'MON-RXBUF',
 b'\x0A\x21': 'MON-RXR',
 b'\x0A\x2E': 'MON-SMGR',
-b'\x0A\x31': 'MON-SPAN',
+# b'\x0A\x31': 'MON-SPAN',
 b'\x0A\x08': 'MON-TXBUF',
+b'\x0A\x04': 'MON-VER',
 b'\x01\x60': 'NAV-AOPSTATUS',
 b'\x01\x05': 'NAV-ATT',
 b'\x01\x22': 'NAV-CLOCK',
@@ -227,6 +252,7 @@ b'\x01\x3B': 'NAV-SVIN',
 b'\x01\x24': 'NAV-TIMEBDS',
 b'\x01\x25': 'NAV-TIMEGAL',
 b'\x01\x23': 'NAV-TIMEGLO',
+b'\x01\x20': 'NAV-TIMEGPS',
 b'\x01\x26': 'NAV-TIMELS',
 b'\x01\x27': 'NAV-TIMEQZSS',
 b'\x01\x21': 'NAV-TIMEUTC',
